VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package IMmailgun

Package {IMmailgun}


Type: Package
Title: Send Emails using 'Mailgun'
Version: 0.1.2
Author: Ignacio Martinez
Maintainer: Ignacio Martinez <ignacio@protonmail.com>
Description: Send emails using the 'mailgun' api. To use this package you will need an account from https://www.mailgun.com .
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: httr
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-09-27 17:10:00 UTC; rstudio
Repository: CRAN
Date/Publication: 2018-10-01 22:40:03 UTC

mailgun factory

Description

Creates an 'IMmailgun' object that allows you to send emails and retrieve stats from your mailgun account.

Usage

mailgun

Format

An object of class R6ClassGenerator of length 24.

Examples

## Not run: 
library(IMmailgun)
url <- "https://api.mailgun.net/v3/email.ignacio.website"
key="~/.ssh/id_rsa"
api_key <- secret::get_secret("mailgun", key = key,
vault = file.path(system.file(package = "IMSecrets"),
"vault/"))[[1]]
from="IMSecrets <postmaster@email.ignacio.website>"
email_client <- mailgun$new(url = url, api_key = api_key, from = from)
email_client$sendEmail(to = c("ignacio82@gmail.com", "ignacio@protonmail.com"),
subject = "Test", plaintext = "Hola!")

## End(Not run)

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.