| Title: | Send Emails using 'Mailgun' |
|---|---|
| Description: | Send emails using the 'mailgun' api. To use this package you will need an account from <https://www.mailgun.com> . |
| Authors: | Ignacio Martinez |
| Maintainer: | Ignacio Martinez <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-05-07 06:36:32 UTC |
| Source: | https://github.com/cran/IMmailgun |
Creates an 'IMmailgun' object that allows you to send emails and retrieve stats from your mailgun account.
mailgunmailgun
An object of class R6ClassGenerator of length 24.
## Not run: library(IMmailgun) url <- "https://api.mailgun.net/v3/email.ignacio.website" key="~/.ssh/id_rsa" api_key <- secret::get_secret("mailgun", key = key, vault = file.path(system.file(package = "IMSecrets"), "vault/"))[[1]] from="IMSecrets <[email protected]>" email_client <- mailgun$new(url = url, api_key = api_key, from = from) email_client$sendEmail(to = c("[email protected]", "[email protected]"), subject = "Test", plaintext = "Hola!") ## End(Not run)## Not run: library(IMmailgun) url <- "https://api.mailgun.net/v3/email.ignacio.website" key="~/.ssh/id_rsa" api_key <- secret::get_secret("mailgun", key = key, vault = file.path(system.file(package = "IMSecrets"), "vault/"))[[1]] from="IMSecrets <[email protected]>" email_client <- mailgun$new(url = url, api_key = api_key, from = from) email_client$sendEmail(to = c("[email protected]", "[email protected]"), subject = "Test", plaintext = "Hola!") ## End(Not run)